v1.0.2
======

Updated README to link to issue that inspired the package.

v1.0.1
======

Add some minimal documentation to the readme.

v1.0.0
======

Initial implementation of a ``-m jaraco.zstd`` command.
